# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/resource_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import origin_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2
from yandex.cloud.cdn.v1 import resource_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/cdn/v1/resource_service.proto',
  package='yandex.cloud.cdn.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/cdn/v1/resource_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/cdn/v1/origin.proto\x1a\"yandex/cloud/cdn/v1/resource.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"7\n\x12GetResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"u\n\x14ListResourcesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"b\n\x15ListResourcesResponse\x12\x30\n\tresources\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.cdn.v1.Resource\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdd\x04\n\x15\x43reateResourceRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x13\n\x05\x63name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12G\n\x06origin\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.CreateResourceRequest.OriginB\x04\xe8\xc7\x31\x01\x12\x44\n\x13secondary_hostnames\x18\x04 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SecondaryHostnames\x12<\n\x0forigin_protocol\x18\x05 \x01(\x0e\x32#.yandex.cloud.cdn.v1.OriginProtocol\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x07options\x18\x07 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\x12\x42\n\x0fssl_certificate\x18\x08 \x01(\x0b\x32).yandex.cloud.cdn.v1.SSLTargetCertificate\x1a\x99\x01\n\x06Origin\x12\x19\n\x0forigin_group_id\x18\x01 \x01(\x03H\x00\x12\x17\n\rorigin_source\x18\x02 \x01(\tH\x00\x12I\n\x14origin_source_params\x18\x03 \x01(\x0b\x32).yandex.cloud.cdn.v1.ResourceOriginParamsH\x00\x42\x10\n\x0eorigin_variant\"U\n\x14ResourceOriginParams\x12\x0e\n\x06source\x18\x01 \x01(\t\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yandex.cloud.cdn.v1.OriginMeta\";\n\x16\x43reateResourceMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x9b\x03\n\x15UpdateResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\x0forigin_group_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x13secondary_hostnames\x18\x03 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SecondaryHostnames\x12\x35\n\x07options\x18\x04 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\x12<\n\x0forigin_protocol\x18\x05 \x01(\x0e\x32#.yandex.cloud.cdn.v1.OriginProtocol\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x0fssl_certificate\x18\x07 \x01(\x0b\x32).yandex.cloud.cdn.v1.SSLTargetCertificate\";\n\x16UpdateResourceMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\":\n\x15\x44\x65leteResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteResourceMetadata\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\":\n\x17GetProviderCNameRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x18GetProviderCNameResponse\x12\r\n\x05\x63name\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t2\x98\x07\n\x0fResourceService\x12v\n\x03Get\x12\'.yandex.cloud.cdn.v1.GetResourceRequest\x1a\x1d.yandex.cloud.cdn.v1.Resource\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/cdn/v1/resources/{resource_id}\x12x\n\x04List\x12).yandex.cloud.cdn.v1.ListResourcesRequest\x1a*.yandex.cloud.cdn.v1.ListResourcesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/cdn/v1/resources\x12\x9b\x01\n\x06\x43reate\x12*.yandex.cloud.cdn.v1.CreateResourceRequest\x1a!.yandex.cloud.operation.Operation\"B\x82\xd3\xe4\x93\x02\x16\"\x11/cdn/v1/resources:\x01*\xb2\xd2*\"\n\x16\x43reateResourceMetadata\x12\x08Resource\x12\xa9\x01\n\x06Update\x12*.yandex.cloud.cdn.v1.UpdateResourceRequest\x1a!.yandex.cloud.operation.Operation\"P\x82\xd3\xe4\x93\x02$2\x1f/cdn/v1/resources/{resource_id}:\x01*\xb2\xd2*\"\n\x16UpdateResourceMetadata\x12\x08Resource\x12\xb3\x01\n\x06\x44\x65lete\x12*.yandex.cloud.cdn.v1.DeleteResourceRequest\x1a!.yandex.cloud.operation.Operation\"Z\x82\xd3\xe4\x93\x02!*\x1f/cdn/v1/resources/{resource_id}\xb2\xd2*/\n\x16\x44\x65leteResourceMetadata\x12\x15google.protobuf.Empty\x12\x92\x01\n\x10GetProviderCName\x12,.yandex.cloud.cdn.v1.GetProviderCNameRequest\x1a-.yandex.cloud.cdn.v1.GetProviderCNameResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/cdn/v1/cname/{folder_id}BV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2.DESCRIPTOR,yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETRESOURCEREQUEST = _descriptor.Descriptor(
  name='GetResourceRequest',
  full_name='yandex.cloud.cdn.v1.GetResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.GetResourceRequest.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=359,
)


_LISTRESOURCESREQUEST = _descriptor.Descriptor(
  name='ListResourcesRequest',
  full_name='yandex.cloud.cdn.v1.ListResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.ListResourcesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.cdn.v1.ListResourcesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.cdn.v1.ListResourcesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=478,
)


_LISTRESOURCESRESPONSE = _descriptor.Descriptor(
  name='ListResourcesResponse',
  full_name='yandex.cloud.cdn.v1.ListResourcesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.cdn.v1.ListResourcesResponse.resources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.cdn.v1.ListResourcesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=578,
)


_CREATERESOURCEREQUEST_ORIGIN = _descriptor.Descriptor(
  name='Origin',
  full_name='yandex.cloud.cdn.v1.CreateResourceRequest.Origin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.Origin.origin_group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_source', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.Origin.origin_source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_source_params', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.Origin.origin_source_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='origin_variant', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.Origin.origin_variant',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1033,
  serialized_end=1186,
)

_CREATERESOURCEREQUEST = _descriptor.Descriptor(
  name='CreateResourceRequest',
  full_name='yandex.cloud.cdn.v1.CreateResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cname', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.cname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.origin', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_hostnames', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.secondary_hostnames', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_protocol', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.origin_protocol', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.active', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.options', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_certificate', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.ssl_certificate', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATERESOURCEREQUEST_ORIGIN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=1186,
)


_RESOURCEORIGINPARAMS = _descriptor.Descriptor(
  name='ResourceOriginParams',
  full_name='yandex.cloud.cdn.v1.ResourceOriginParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='yandex.cloud.cdn.v1.ResourceOriginParams.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='yandex.cloud.cdn.v1.ResourceOriginParams.meta', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1188,
  serialized_end=1273,
)


_CREATERESOURCEMETADATA = _descriptor.Descriptor(
  name='CreateResourceMetadata',
  full_name='yandex.cloud.cdn.v1.CreateResourceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.CreateResourceMetadata.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1275,
  serialized_end=1334,
)


_UPDATERESOURCEREQUEST = _descriptor.Descriptor(
  name='UpdateResourceRequest',
  full_name='yandex.cloud.cdn.v1.UpdateResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.origin_group_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_hostnames', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.secondary_hostnames', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.options', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_protocol', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.origin_protocol', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.active', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_certificate', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.ssl_certificate', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1337,
  serialized_end=1748,
)


_UPDATERESOURCEMETADATA = _descriptor.Descriptor(
  name='UpdateResourceMetadata',
  full_name='yandex.cloud.cdn.v1.UpdateResourceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.UpdateResourceMetadata.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1809,
)


_DELETERESOURCEREQUEST = _descriptor.Descriptor(
  name='DeleteResourceRequest',
  full_name='yandex.cloud.cdn.v1.DeleteResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.DeleteResourceRequest.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1811,
  serialized_end=1869,
)


_DELETERESOURCEMETADATA = _descriptor.Descriptor(
  name='DeleteResourceMetadata',
  full_name='yandex.cloud.cdn.v1.DeleteResourceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.DeleteResourceMetadata.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1871,
  serialized_end=1916,
)


_GETPROVIDERCNAMEREQUEST = _descriptor.Descriptor(
  name='GetProviderCNameRequest',
  full_name='yandex.cloud.cdn.v1.GetProviderCNameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.GetProviderCNameRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1918,
  serialized_end=1976,
)


_GETPROVIDERCNAMERESPONSE = _descriptor.Descriptor(
  name='GetProviderCNameResponse',
  full_name='yandex.cloud.cdn.v1.GetProviderCNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cname', full_name='yandex.cloud.cdn.v1.GetProviderCNameResponse.cname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.GetProviderCNameResponse.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1978,
  serialized_end=2038,
)

_LISTRESOURCESRESPONSE.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._RESOURCE
_CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_source_params'].message_type = _RESOURCEORIGINPARAMS
_CREATERESOURCEREQUEST_ORIGIN.containing_type = _CREATERESOURCEREQUEST
_CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant'].fields.append(
  _CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_group_id'])
_CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_group_id'].containing_oneof = _CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant']
_CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant'].fields.append(
  _CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_source'])
_CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_source'].containing_oneof = _CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant']
_CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant'].fields.append(
  _CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_source_params'])
_CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_source_params'].containing_oneof = _CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant']
_CREATERESOURCEREQUEST.fields_by_name['origin'].message_type = _CREATERESOURCEREQUEST_ORIGIN
_CREATERESOURCEREQUEST.fields_by_name['secondary_hostnames'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._SECONDARYHOSTNAMES
_CREATERESOURCEREQUEST.fields_by_name['origin_protocol'].enum_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._ORIGINPROTOCOL
_CREATERESOURCEREQUEST.fields_by_name['active'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CREATERESOURCEREQUEST.fields_by_name['options'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._RESOURCEOPTIONS
_CREATERESOURCEREQUEST.fields_by_name['ssl_certificate'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._SSLTARGETCERTIFICATE
_RESOURCEORIGINPARAMS.fields_by_name['meta'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2._ORIGINMETA
_UPDATERESOURCEREQUEST.fields_by_name['origin_group_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_UPDATERESOURCEREQUEST.fields_by_name['secondary_hostnames'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._SECONDARYHOSTNAMES
_UPDATERESOURCEREQUEST.fields_by_name['options'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._RESOURCEOPTIONS
_UPDATERESOURCEREQUEST.fields_by_name['origin_protocol'].enum_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._ORIGINPROTOCOL
_UPDATERESOURCEREQUEST.fields_by_name['active'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_UPDATERESOURCEREQUEST.fields_by_name['ssl_certificate'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._SSLTARGETCERTIFICATE
DESCRIPTOR.message_types_by_name['GetResourceRequest'] = _GETRESOURCEREQUEST
DESCRIPTOR.message_types_by_name['ListResourcesRequest'] = _LISTRESOURCESREQUEST
DESCRIPTOR.message_types_by_name['ListResourcesResponse'] = _LISTRESOURCESRESPONSE
DESCRIPTOR.message_types_by_name['CreateResourceRequest'] = _CREATERESOURCEREQUEST
DESCRIPTOR.message_types_by_name['ResourceOriginParams'] = _RESOURCEORIGINPARAMS
DESCRIPTOR.message_types_by_name['CreateResourceMetadata'] = _CREATERESOURCEMETADATA
DESCRIPTOR.message_types_by_name['UpdateResourceRequest'] = _UPDATERESOURCEREQUEST
DESCRIPTOR.message_types_by_name['UpdateResourceMetadata'] = _UPDATERESOURCEMETADATA
DESCRIPTOR.message_types_by_name['DeleteResourceRequest'] = _DELETERESOURCEREQUEST
DESCRIPTOR.message_types_by_name['DeleteResourceMetadata'] = _DELETERESOURCEMETADATA
DESCRIPTOR.message_types_by_name['GetProviderCNameRequest'] = _GETPROVIDERCNAMEREQUEST
DESCRIPTOR.message_types_by_name['GetProviderCNameResponse'] = _GETPROVIDERCNAMERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetResourceRequest = _reflection.GeneratedProtocolMessageType('GetResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCEREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.GetResourceRequest)
  })
_sym_db.RegisterMessage(GetResourceRequest)

ListResourcesRequest = _reflection.GeneratedProtocolMessageType('ListResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESOURCESREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ListResourcesRequest)
  })
_sym_db.RegisterMessage(ListResourcesRequest)

ListResourcesResponse = _reflection.GeneratedProtocolMessageType('ListResourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESOURCESRESPONSE,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ListResourcesResponse)
  })
_sym_db.RegisterMessage(ListResourcesResponse)

CreateResourceRequest = _reflection.GeneratedProtocolMessageType('CreateResourceRequest', (_message.Message,), {

  'Origin' : _reflection.GeneratedProtocolMessageType('Origin', (_message.Message,), {
    'DESCRIPTOR' : _CREATERESOURCEREQUEST_ORIGIN,
    '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.CreateResourceRequest.Origin)
    })
  ,
  'DESCRIPTOR' : _CREATERESOURCEREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.CreateResourceRequest)
  })
_sym_db.RegisterMessage(CreateResourceRequest)
_sym_db.RegisterMessage(CreateResourceRequest.Origin)

ResourceOriginParams = _reflection.GeneratedProtocolMessageType('ResourceOriginParams', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEORIGINPARAMS,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOriginParams)
  })
_sym_db.RegisterMessage(ResourceOriginParams)

CreateResourceMetadata = _reflection.GeneratedProtocolMessageType('CreateResourceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCEMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.CreateResourceMetadata)
  })
_sym_db.RegisterMessage(CreateResourceMetadata)

UpdateResourceRequest = _reflection.GeneratedProtocolMessageType('UpdateResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCEREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.UpdateResourceRequest)
  })
_sym_db.RegisterMessage(UpdateResourceRequest)

UpdateResourceMetadata = _reflection.GeneratedProtocolMessageType('UpdateResourceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCEMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.UpdateResourceMetadata)
  })
_sym_db.RegisterMessage(UpdateResourceMetadata)

DeleteResourceRequest = _reflection.GeneratedProtocolMessageType('DeleteResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERESOURCEREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.DeleteResourceRequest)
  })
_sym_db.RegisterMessage(DeleteResourceRequest)

DeleteResourceMetadata = _reflection.GeneratedProtocolMessageType('DeleteResourceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETERESOURCEMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.DeleteResourceMetadata)
  })
_sym_db.RegisterMessage(DeleteResourceMetadata)

GetProviderCNameRequest = _reflection.GeneratedProtocolMessageType('GetProviderCNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROVIDERCNAMEREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.GetProviderCNameRequest)
  })
_sym_db.RegisterMessage(GetProviderCNameRequest)

GetProviderCNameResponse = _reflection.GeneratedProtocolMessageType('GetProviderCNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROVIDERCNAMERESPONSE,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.GetProviderCNameResponse)
  })
_sym_db.RegisterMessage(GetProviderCNameResponse)


DESCRIPTOR._options = None
_GETRESOURCEREQUEST.fields_by_name['resource_id']._options = None
_LISTRESOURCESREQUEST.fields_by_name['folder_id']._options = None
_LISTRESOURCESREQUEST.fields_by_name['page_size']._options = None
_LISTRESOURCESREQUEST.fields_by_name['page_token']._options = None
_CREATERESOURCEREQUEST.fields_by_name['folder_id']._options = None
_CREATERESOURCEREQUEST.fields_by_name['cname']._options = None
_CREATERESOURCEREQUEST.fields_by_name['origin']._options = None
_CREATERESOURCEMETADATA.fields_by_name['resource_id']._options = None
_UPDATERESOURCEREQUEST.fields_by_name['resource_id']._options = None
_UPDATERESOURCEMETADATA.fields_by_name['resource_id']._options = None
_DELETERESOURCEREQUEST.fields_by_name['resource_id']._options = None
_GETPROVIDERCNAMEREQUEST.fields_by_name['folder_id']._options = None

_RESOURCESERVICE = _descriptor.ServiceDescriptor(
  name='ResourceService',
  full_name='yandex.cloud.cdn.v1.ResourceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2041,
  serialized_end=2961,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.cdn.v1.ResourceService.Get',
    index=0,
    containing_service=None,
    input_type=_GETRESOURCEREQUEST,
    output_type=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._RESOURCE,
    serialized_options=b'\202\323\344\223\002!\022\037/cdn/v1/resources/{resource_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.cdn.v1.ResourceService.List',
    index=1,
    containing_service=None,
    input_type=_LISTRESOURCESREQUEST,
    output_type=_LISTRESOURCESRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/cdn/v1/resources',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.cdn.v1.ResourceService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATERESOURCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\026\"\021/cdn/v1/resources:\001*\262\322*\"\n\026CreateResourceMetadata\022\010Resource',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.cdn.v1.ResourceService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATERESOURCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$2\037/cdn/v1/resources/{resource_id}:\001*\262\322*\"\n\026UpdateResourceMetadata\022\010Resource',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.cdn.v1.ResourceService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETERESOURCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002!*\037/cdn/v1/resources/{resource_id}\262\322*/\n\026DeleteResourceMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProviderCName',
    full_name='yandex.cloud.cdn.v1.ResourceService.GetProviderCName',
    index=5,
    containing_service=None,
    input_type=_GETPROVIDERCNAMEREQUEST,
    output_type=_GETPROVIDERCNAMERESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/cdn/v1/cname/{folder_id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RESOURCESERVICE)

DESCRIPTOR.services_by_name['ResourceService'] = _RESOURCESERVICE

# @@protoc_insertion_point(module_scope)
