# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/greenplum/v1/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/greenplum/v1/config.proto',
  package='yandex.cloud.mdb.greenplum.v1',
  syntax='proto3',
  serialized_options=b'\n!yandex.cloud.api.mdb.greenplum.v1B\004GPCFZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/mdb/greenplum/v1/config.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"\x9e\x01\n\x16MasterSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\x12G\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet\"\xa0\x01\n\x17SegmentSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\x12H\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet\"\xb5\x02\n\x15GreenplumMasterConfig\x12P\n\tlog_level\x18\x01 \x01(\x0e\x32=.yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig.LogLevel\x12\x34\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12.\n\x08timezone\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"d\n\x08LogLevel\x12\x19\n\x15LOG_LEVEL_UNSPECIFIED\x10\x00\x12\t\n\x05TRACE\x10\x01\x12\t\n\x05\x44\x45\x42UG\x10\x02\x12\x0f\n\x0bINFORMATION\x10\x03\x12\x0b\n\x07WARNING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\"\x87\x02\n\x16GreenplumSegmentConfig\x12Q\n\tlog_level\x18\x01 \x01(\x0e\x32>.yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig.LogLevel\x12\x34\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"d\n\x08LogLevel\x12\x19\n\x15LOG_LEVEL_UNSPECIFIED\x10\x00\x12\t\n\x05TRACE\x10\x01\x12\t\n\x05\x44\x45\x42UG\x10\x02\x12\x0f\n\x0bINFORMATION\x10\x03\x12\x0b\n\x07WARNING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\"\x89\x02\n\x18GreenplumMasterConfigSet\x12T\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigB\x04\xe8\xc7\x31\x01\x12I\n\x0buser_config\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig\x12L\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig\"\x8d\x02\n\x19GreenplumSegmentConfigSet\x12U\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigB\x04\xe8\xc7\x31\x01\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigBv\n!yandex.cloud.api.mdb.greenplum.v1B\x04GPCFZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_GREENPLUMMASTERCONFIG_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFORMATION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=756,
  serialized_end=856,
)
_sym_db.RegisterEnumDescriptor(_GREENPLUMMASTERCONFIG_LOGLEVEL)

_GREENPLUMSEGMENTCONFIG_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFORMATION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=756,
  serialized_end=856,
)
_sym_db.RegisterEnumDescriptor(_GREENPLUMSEGMENTCONFIG_LOGLEVEL)


_RESOURCES = _descriptor.Descriptor(
  name='Resources',
  full_name='yandex.cloud.mdb.greenplum.v1.Resources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_preset_id', full_name='yandex.cloud.mdb.greenplum.v1.Resources.resource_preset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_size', full_name='yandex.cloud.mdb.greenplum.v1.Resources.disk_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_type_id', full_name='yandex.cloud.mdb.greenplum.v1.Resources.disk_type_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=220,
)


_MASTERSUBCLUSTERCONFIG = _descriptor.Descriptor(
  name='MasterSubclusterConfig',
  full_name='yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=381,
)


_SEGMENTSUBCLUSTERCONFIG = _descriptor.Descriptor(
  name='SegmentSubclusterConfig',
  full_name='yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=544,
)


_GREENPLUMMASTERCONFIG = _descriptor.Descriptor(
  name='GreenplumMasterConfig',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_level', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig.log_level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_connections', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig.max_connections', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig.timezone', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GREENPLUMMASTERCONFIG_LOGLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=856,
)


_GREENPLUMSEGMENTCONFIG = _descriptor.Descriptor(
  name='GreenplumSegmentConfig',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_level', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig.log_level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_connections', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig.max_connections', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GREENPLUMSEGMENTCONFIG_LOGLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=1122,
)


_GREENPLUMMASTERCONFIGSET = _descriptor.Descriptor(
  name='GreenplumMasterConfigSet',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1125,
  serialized_end=1390,
)


_GREENPLUMSEGMENTCONFIGSET = _descriptor.Descriptor(
  name='GreenplumSegmentConfigSet',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1662,
)

_MASTERSUBCLUSTERCONFIG.fields_by_name['resources'].message_type = _RESOURCES
_MASTERSUBCLUSTERCONFIG.fields_by_name['config'].message_type = _GREENPLUMMASTERCONFIGSET
_SEGMENTSUBCLUSTERCONFIG.fields_by_name['resources'].message_type = _RESOURCES
_SEGMENTSUBCLUSTERCONFIG.fields_by_name['config'].message_type = _GREENPLUMSEGMENTCONFIGSET
_GREENPLUMMASTERCONFIG.fields_by_name['log_level'].enum_type = _GREENPLUMMASTERCONFIG_LOGLEVEL
_GREENPLUMMASTERCONFIG.fields_by_name['max_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMMASTERCONFIG.fields_by_name['timezone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GREENPLUMMASTERCONFIG_LOGLEVEL.containing_type = _GREENPLUMMASTERCONFIG
_GREENPLUMSEGMENTCONFIG.fields_by_name['log_level'].enum_type = _GREENPLUMSEGMENTCONFIG_LOGLEVEL
_GREENPLUMSEGMENTCONFIG.fields_by_name['max_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMSEGMENTCONFIG_LOGLEVEL.containing_type = _GREENPLUMSEGMENTCONFIG
_GREENPLUMMASTERCONFIGSET.fields_by_name['effective_config'].message_type = _GREENPLUMMASTERCONFIG
_GREENPLUMMASTERCONFIGSET.fields_by_name['user_config'].message_type = _GREENPLUMMASTERCONFIG
_GREENPLUMMASTERCONFIGSET.fields_by_name['default_config'].message_type = _GREENPLUMMASTERCONFIG
_GREENPLUMSEGMENTCONFIGSET.fields_by_name['effective_config'].message_type = _GREENPLUMSEGMENTCONFIG
_GREENPLUMSEGMENTCONFIGSET.fields_by_name['user_config'].message_type = _GREENPLUMSEGMENTCONFIG
_GREENPLUMSEGMENTCONFIGSET.fields_by_name['default_config'].message_type = _GREENPLUMSEGMENTCONFIG
DESCRIPTOR.message_types_by_name['Resources'] = _RESOURCES
DESCRIPTOR.message_types_by_name['MasterSubclusterConfig'] = _MASTERSUBCLUSTERCONFIG
DESCRIPTOR.message_types_by_name['SegmentSubclusterConfig'] = _SEGMENTSUBCLUSTERCONFIG
DESCRIPTOR.message_types_by_name['GreenplumMasterConfig'] = _GREENPLUMMASTERCONFIG
DESCRIPTOR.message_types_by_name['GreenplumSegmentConfig'] = _GREENPLUMSEGMENTCONFIG
DESCRIPTOR.message_types_by_name['GreenplumMasterConfigSet'] = _GREENPLUMMASTERCONFIGSET
DESCRIPTOR.message_types_by_name['GreenplumSegmentConfigSet'] = _GREENPLUMSEGMENTCONFIGSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Resources = _reflection.GeneratedProtocolMessageType('Resources', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCES,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.Resources)
  })
_sym_db.RegisterMessage(Resources)

MasterSubclusterConfig = _reflection.GeneratedProtocolMessageType('MasterSubclusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _MASTERSUBCLUSTERCONFIG,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig)
  })
_sym_db.RegisterMessage(MasterSubclusterConfig)

SegmentSubclusterConfig = _reflection.GeneratedProtocolMessageType('SegmentSubclusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTSUBCLUSTERCONFIG,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig)
  })
_sym_db.RegisterMessage(SegmentSubclusterConfig)

GreenplumMasterConfig = _reflection.GeneratedProtocolMessageType('GreenplumMasterConfig', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMMASTERCONFIG,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig)
  })
_sym_db.RegisterMessage(GreenplumMasterConfig)

GreenplumSegmentConfig = _reflection.GeneratedProtocolMessageType('GreenplumSegmentConfig', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMSEGMENTCONFIG,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig)
  })
_sym_db.RegisterMessage(GreenplumSegmentConfig)

GreenplumMasterConfigSet = _reflection.GeneratedProtocolMessageType('GreenplumMasterConfigSet', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMMASTERCONFIGSET,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet)
  })
_sym_db.RegisterMessage(GreenplumMasterConfigSet)

GreenplumSegmentConfigSet = _reflection.GeneratedProtocolMessageType('GreenplumSegmentConfigSet', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMSEGMENTCONFIGSET,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet)
  })
_sym_db.RegisterMessage(GreenplumSegmentConfigSet)


DESCRIPTOR._options = None
_GREENPLUMMASTERCONFIGSET.fields_by_name['effective_config']._options = None
_GREENPLUMSEGMENTCONFIGSET.fields_by_name['effective_config']._options = None
# @@protoc_insertion_point(module_scope)
